Redis Transport - kombu.transport.pyredis — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# Redis Transport - kombu.transport.pyredis

class `kombu.transport.pyredis.` `Channel`(connection, **kwargs)
  `client`
  `close`()

class `kombu.transport.pyredis.` `Transport`(client, **kwargs)
  class `Channel`(connection, **kwargs)
    `client`
    `close`()

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »